<?php
session_start();
require_once 'includes/firestore_helper.php';
require_once 'includes/subscription_middleware.php';

// Check authentication and subscription
checkSubscription();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $data = json_decode(file_get_contents('php://input'), true);
    
    // Validate input
    if (!filter_var($data['ip_address'], FILTER_VALIDATE_IP)) {
        http_response_code(400);
        echo json_encode(['error' => 'Invalid IP address']);
        exit();
    }

    if (!is_numeric($data['port']) || $data['port'] < 1 || $data['port'] > 65535) {
        http_response_code(400);
        echo json_encode(['error' => 'Invalid port number']);
        exit();
    }

    $firestoreHelper = new FirestoreHelper($_SESSION['user_id']);
    
    try {
        // Check IP address limit based on subscription
        $currentIps = $firestoreHelper->getIpAddresses();
        $userDoc = $firestoreHelper->getUserData($_SESSION['user_id']);
        $subscriptionType = $userDoc['subscription']['type'];
        
        $ipLimits = [
            'free' => 3,
            'basic' => 10,
            'premium' => 50
        ];

        if (count($currentIps) >= $ipLimits[$subscriptionType]) {
            throw new Exception('IP address limit reached for your subscription plan');
        }

        $firestoreHelper->addIpAddress($data['ip_address'], $data['port'], $data['url']);
        echo json_encode(['success' => true]);
    } catch (Exception $e) {
        http_response_code(500);
        echo json_encode(['error' => $e->getMessage()]);
    }
}
?>
