<?php
session_start();
require_once '../includes/firebase_init.php';

if (!isset($_SESSION['is_admin']) || !$_SESSION['is_admin']) {
    header('Location: ../login.php');
    exit();
}

$userId = $_GET['id'] ?? null;
if (!$userId) {
    header('Location: index.php');
    exit();
}

$firebase = FirebaseInit::getInstance();
$firestore = $firebase->getFirestore();

$userDoc = $firestore->collection('users')->document($userId)->snapshot();
if (!$userDoc->exists()) {
    header('Location: index.php');
    exit();
}

$userData = $userDoc->data();
$plans = $firestore->collection('subscription_plans')->documents();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit User</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap">
    <link rel="stylesheet" href="../styles.css">
</head>
<body>
    <div class="admin-container">
        <h1>Edit User</h1>
        <form id="editUserForm">
            <input type="hidden" name="userId" value="<?= $userId ?>">
            
            <div class="form-group">
                <label>Email:</label>
                <input type="email" name="email" value="<?= htmlspecialchars($userData['email']) ?>" readonly>
            </div>
            
            <div class="form-group">
                <label>Subscription Type:</label>
                <select name="subscription_type" required>
                    <?php foreach ($plans as $plan): ?>
                        <?php $planData = $plan->data(); ?>
                        <option value="<?= $plan->id() ?>" 
                            <?= ($userData['subscription']['type'] === $planData['name']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($planData['name']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            
            <div class="form-group">
                <label>Subscription End Date:</label>
                <input type="date" name="end_date" 
                    value="<?= date('Y-m-d', strtotime($userData['subscription']['endDate'])) ?>" 
                    required>
            </div>
            
            <button type="submit" class="action-btn">Update User</button>
        </form>
    </div>

    <script>
        document.getElementById('editUserForm').addEventListener('submit', async (e) => {
            e.preventDefault();
            const formData = new FormData(e.target);
            
            try {
                const response = await fetch('update_user.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        userId: formData.get('userId'),
                        subscriptionType: formData.get('subscription_type'),
                        endDate: formData.get('end_date')
                    })
                });

                if (response.ok) {
                    window.location.href = 'index.php';
                } else {
                    throw new Error('Failed to update user');
                }
            } catch (error) {
                alert(error.message);
            }
        });
    </script>
</body>
</html> 