<?php
session_start();
require_once '../includes/firebase_init.php';

// Check if user is admin
if (!isset($_SESSION['authenticated']) || !isset($_SESSION['is_admin']) || !$_SESSION['is_admin']) {
    header('Location: ../login.php');
    exit();
}

$firebase = FirebaseInit::getInstance();
$firestore = $firebase->getFirestore();

// Get all users
$users = $firestore->collection('users')->documents();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap">
    <link rel="stylesheet" href="../styles.css">
    <style>
        .admin-container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }
        
        .user-table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            background: white;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
        }
        
        .user-table th, .user-table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }
        
        .user-table th {
            background-color: #fc6933;
            color: white;
        }
        
        .user-table tr:hover {
            background-color: #f5f5f5;
        }
        
        .action-btn {
            padding: 6px 12px;
            border-radius: 4px;
            border: none;
            cursor: pointer;
            margin-right: 5px;
        }
        
        .edit-btn {
            background-color: #4CAF50;
            color: white;
        }
        
        .delete-btn {
            background-color: #f44336;
            color: white;
        }
    </style>
</head>
<body>
    <div class="admin-container">
        <h1>Admin Dashboard</h1>
        <div class="admin-actions">
            <button onclick="window.location.href='manage_subscriptions.php'" class="action-btn">
                Manage Subscription Plans
            </button>
        </div>
        
        <table class="user-table">
            <thead>
                <tr>
                    <th>Email</th>
                    <th>Subscription Type</th>
                    <th>Expiration Date</th>
                    <th>IP Count</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($users as $user): ?>
                    <?php 
                    $userData = $user->data();
                    $ipCount = $firestore->collection('users')->document($user->id())
                        ->collection('ip_addresses')->documents()->size();
                    ?>
                    <tr>
                        <td><?= htmlspecialchars($userData['email']) ?></td>
                        <td><?= ucfirst($userData['subscription']['type']) ?></td>
                        <td><?= $userData['subscription']['endDate'] ?></td>
                        <td><?= $ipCount ?></td>
                        <td>
                            <button onclick="editUser('<?= $user->id() ?>')" class="action-btn edit-btn">Edit</button>
                            <button onclick="deleteUser('<?= $user->id() ?>')" class="action-btn delete-btn">Delete</button>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <script>
        async function editUser(userId) {
            window.location.href = `edit_user.php?id=${userId}`;
        }

        async function deleteUser(userId) {
            if (!confirm('Are you sure you want to delete this user?')) return;
            
            try {
                const response = await fetch('delete_user.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ userId })
                });

                if (response.ok) {
                    window.location.reload();
                } else {
                    throw new Error('Failed to delete user');
                }
            } catch (error) {
                alert(error.message);
            }
        }
    </script>
</body>
</html> 