<?php
session_start();
require_once '../includes/firebase_init.php';

if (!isset($_SESSION['is_admin']) || !$_SESSION['is_admin']) {
    header('Location: ../login.php');
    exit();
}

$firebase = FirebaseInit::getInstance();
$firestore = $firebase->getFirestore();

// Get subscription plans
$plans = $firestore->collection('subscription_plans')->documents();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Subscriptions</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap">
    <link rel="stylesheet" href="../styles.css">
    <style>
        .plan-card {
            background: white;
            border-radius: 8px;
            padding: 20px;
            margin: 10px 0;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
        }
        
        .plan-form {
            max-width: 500px;
            margin: 20px 0;
        }
        
        .plan-form input {
            width: 100%;
            padding: 8px;
            margin: 5px 0;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
    </style>
</head>
<body>
    <div class="admin-container">
        <h1>Manage Subscription Plans</h1>
        
        <div class="plan-form">
            <h2>Add New Plan</h2>
            <form id="addPlanForm">
                <input type="text" name="name" placeholder="Plan Name" required>
                <input type="number" name="price" placeholder="Price" required>
                <input type="number" name="duration" placeholder="Duration (days)" required>
                <input type="number" name="ip_limit" placeholder="IP Address Limit" required>
                <button type="submit" class="action-btn">Add Plan</button>
            </form>
        </div>

        <div class="existing-plans">
            <h2>Existing Plans</h2>
            <?php foreach ($plans as $plan): ?>
                <?php $planData = $plan->data(); ?>
                <div class="plan-card">
                    <h3><?= htmlspecialchars($planData['name']) ?></h3>
                    <p>Price: $<?= number_format($planData['price'], 2) ?></p>
                    <p>Duration: <?= $planData['duration'] ?> days</p>
                    <p>IP Limit: <?= $planData['ip_limit'] ?></p>
                    <button onclick="editPlan('<?= $plan->id() ?>')" class="action-btn edit-btn">Edit</button>
                    <button onclick="deletePlan('<?= $plan->id() ?>')" class="action-btn delete-btn">Delete</button>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <script>
        document.getElementById('addPlanForm').addEventListener('submit', async (e) => {
            e.preventDefault();
            const formData = new FormData(e.target);
            
            try {
                const response = await fetch('add_plan.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        name: formData.get('name'),
                        price: parseFloat(formData.get('price')),
                        duration: parseInt(formData.get('duration')),
                        ip_limit: parseInt(formData.get('ip_limit'))
                    })
                });

                if (response.ok) {
                    window.location.reload();
                } else {
                    throw new Error('Failed to add plan');
                }
            } catch (error) {
                alert(error.message);
            }
        });

        async function editPlan(planId) {
            window.location.href = `edit_plan.php?id=${planId}`;
        }

        async function deletePlan(planId) {
            if (!confirm('Are you sure you want to delete this plan?')) return;
            
            try {
                const response = await fetch('delete_plan.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ planId })
                });

                if (response.ok) {
                    window.location.reload();
                } else {
                    throw new Error('Failed to delete plan');
                }
            } catch (error) {
                alert(error.message);
            }
        }
    </script>
</body>
</html> 