<?php
session_start();
require_once 'includes/firebase_init.php';
require_once 'includes/analytics_helper.php';
require_once 'includes/roles.php';

if (!isset($_SESSION['authenticated'])) {
    header('Location: login.php');
    exit();
}

$analytics = new AnalyticsHelper($_SESSION['user_id']);
$stats = $analytics->getUserStats();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Analytics Dashboard</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap">
    <link rel="stylesheet" href="styles.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>
<body>
    <div class="container">
        <h1>Analytics Dashboard</h1>
        
        <div class="stats-grid">
            <div class="stat-card">
                <h3>Total Checks</h3>
                <p class="stat-number"><?= number_format($stats['total_checks']) ?></p>
            </div>
            
            <div class="stat-card">
                <h3>Average Uptime</h3>
                <p class="stat-number"><?= number_format($stats['uptime_percentage'], 2) ?>%</p>
            </div>
            
            <div class="stat-card">
                <h3>Downtime Incidents (24h)</h3>
                <p class="stat-number"><?= $stats['downtime_incidents'] ?></p>
            </div>
        </div>
        
        <div class="chart-container">
            <canvas id="uptimeChart"></canvas>
        </div>
        
        <div class="ip-stats">
            <h2>IP Address Statistics</h2>
            <table class="stats-table">
                <thead>
                    <tr>
                        <th>IP Address</th>
                        <th>24h Uptime</th>
                        <th>7d Uptime</th>
                        <th>30d Uptime</th>
                        <th>Last Check</th>
                    </tr>
                </thead>
                <tbody id="ipStatsBody">
                    <!-- Filled by JavaScript -->
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // Fetch IP statistics
        async function fetchIpStats() {
            try {
                const response = await fetch('get_ip_stats.php');
                const data = await response.json();
                
                const tbody = document.getElementById('ipStatsBody');
                tbody.innerHTML = '';
                
                data.forEach(ip => {
                    const row = document.createElement('tr');
                    row.innerHTML = `
                        <td>${ip.address}:${ip.port}</td>
                        <td>${ip.uptime_24h.toFixed(2)}%</td>
                        <td>${ip.uptime_7d.toFixed(2)}%</td>
                        <td>${ip.uptime_30d.toFixed(2)}%</td>
                        <td>${new Date(ip.last_check).toLocaleString()}</td>
                    `;
                    tbody.appendChild(row);
                });
            } catch (error) {
                console.error('Failed to fetch IP stats:', error);
            }
        }

        // Initialize uptime chart
        const ctx = document.getElementById('uptimeChart').getContext('2d');
        new Chart(ctx, {
            type: 'line',
            data: {
                labels: [], // Will be filled with dates
                datasets: [{
                    label: 'Uptime Percentage',
                    data: [], // Will be filled with uptime data
                    borderColor: '#fc6933',
                    tension: 0.1
                }]
            },
            options: {
                responsive: true,
                scales: {
                    y: {
                        beginAtZero: true,
                        max: 100
                    }
                }
            }
        });

        // Initial load
        fetchIpStats();
        
        // Refresh every minute
        setInterval(fetchIpStats, 60000);
    </script>
</body>
</html> 