<?php
session_start();
require_once 'includes/firestore_helper.php';
require_once 'includes/analytics_helper.php';

if (!isset($_SESSION['authenticated'])) {
    die("Unauthorized access.");
}

$firestoreHelper = new FirestoreHelper($_SESSION['user_id']);
$firebase = FirebaseAdmin::getInstance();
$firestore = $firebase->getFirestore();
$analytics = new AnalyticsHelper($_SESSION['user_id']);

// Get user's IP addresses
$ipAddresses = $firestoreHelper->getIpAddresses();

// Get user's Telegram chat ID
$userDoc = $firestore->collection('users')->document($_SESSION['user_id'])->snapshot();
$telegram_chat_id = $userDoc->data()['telegramChatId'] ?? null;

function isPortOpen($ip, $port) {
    $connection = @fsockopen($ip, $port, $errno, $errstr, 5);
    if (is_resource($connection)) {
        fclose($connection);
        return true;
    }
    return false;
}

function sendTelegramMessage($message, $telegram_chat_id) {
    $telegramBotToken = $_ENV['TELEGRAM_BOT_TOKEN'];

    $url = "https://api.telegram.org/bot$telegramBotToken/sendMessage";
    $data = [
        'chat_id' => $telegram_chat_id,
        'text' => $message,
    ];

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_TIMEOUT, 30);

    $result = curl_exec($ch);
    curl_close($ch);

    return $result;
}

$results = [];
foreach ($ipAddresses as $entry) {
    $ip = $entry['ipAddress'];
    $port = $entry['port'];
    $url = $entry['url'];

    $status = isPortOpen($ip, $port) ? 'up' : 'down';
    $analytics->logCheck($ip, $port, $status);

    if ($status === 'down') {
        $results[] = "IP $ip:$port is down! | $url";
        if ($telegram_chat_id) {
            sendTelegramMessage("IP $ip:$port is down! | $url", $telegram_chat_id);
        }
    } else {
        $results[] = "IP $ip:$port is up.";
    }
}

// Store results in Firestore
$firestore->collection('check_results')->add([
    'userId' => $_SESSION['user_id'],
    'results' => $results,
    'timestamp' => new \Google\Cloud\Core\Timestamp(new \DateTime())
]);

if (php_sapi_name() != 'cli') {
    foreach ($results as $result) {
        echo "<p>$result</p>";
    }
}
?>
