<?php
session_start();
require_once 'includes/firebase_admin.php';
require_once 'includes/firestore_helper.php';

if (!isset($_SESSION['authenticated'])) {
    header('Location: login.php');
    exit();
}

$userId = $_SESSION['user_id'];
$firestoreHelper = new FirestoreHelper($userId);

// Fetch user data and IP addresses from Firestore
$firebase = FirebaseAdmin::getInstance();
$firestore = $firebase->getFirestore();
$userDoc = $firestore->collection('users')->document($userId)->snapshot();
$userData = $userDoc->data();
$ipAddresses = $firestoreHelper->getIpAddresses();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Client Dashboard</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap">
    <link rel="stylesheet" href="styles.css">
    <style>
        :root {
            --primary-color: #fc6933;
            --secondary-color: #ff9478;
            --background-color: #f7f8fc;
            --card-background: #ffffff;
            --text-color: #2b2b2b;
            --hover-color: #ff9478;
            --border-color: #ddd;
            --shadow-color: rgba(0, 0, 0, 0.1);
            --radius: 12px;
        }

        body {
            font-family: 'Poppins', sans-serif;
            background-color: var(--background-color);
            margin: 0;
            padding: 0;
            color: var(--text-color);
            line-height: 1.6;
        }
        .container {
            max-width: 1100px;
            margin: 0 auto;
            padding: 20px;
        }
        .header {
            text-align: center;
            margin-bottom: 40px;
        }
        .header h1 {
            color: var(--primary-color);
            font-size: 2.5em;
            margin: 0;
            font-weight: 600;
        }
        .dashboard {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
        }
        .card {
            background-color: var(--card-background);
            border-radius: var(--radius);
            box-shadow: 0 4px 20px var(--shadow-color);
            padding: 20px;
            box-sizing: border-box;
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            width: 100%;
            max-width: 350px;
        }
        .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 30px rgba(0, 0, 0, 0.2);
        }
        .card h2 {
            margin-bottom: 20px;
            color: var(--primary-color);
            font-size: 1.8em;
            font-weight: 600;
        }
        .card p {
            margin-bottom: 15px;
            font-size: 1em;
        }

        .combined-card {
            flex: 1;
            background-color: var(--card-background);
            border-radius: var(--radius);
            box-shadow: 0 4px 20px var(--shadow-color);
            padding: 20px;
            box-sizing: border-box;
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            margin-top: 20px;
            max-width: 350px;
        }
        .combined-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 30px rgba(0, 0, 0, 0.2);
        }
        .combined-card h2 {
            margin-bottom: 20px;
            color: var(--primary-color);
            font-size: 1.8em;
            font-weight: 600;
        }

        .main-card {
            flex: 1;
            background-color: var(--card-background);
            border-radius: var(--radius);
            box-shadow: 0 4px 20px var(--shadow-color);
            padding: 20px;
            box-sizing: border-box;
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            margin-top: 20px;
        }
        .main-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 30px rgba(0, 0, 0, 0.2);
        }
        .main-card h2 {
            margin-bottom: 20px;
            color: var(--primary-color);
            font-size: 2em;
            font-weight: 600;
        }
        .main-card ul {
            list-style-type: none;
            padding: 0;
        }
        .main-card ul li {
            background: var(--background-color);
            margin: 10px 0;
            padding: 12px 15px;
            border-radius: var(--radius);
            display: flex;
            justify-content: space-between;
            align-items: center;
            border: 1px solid var(--border-color);
            text-align: left; /* Ensures the text is aligned to the left */
        }
        .main-card ul li a {
            color: var(--primary-color);
            text-decoration: none;
            font-weight: 500;
            transition: color 0.3s ease;
            flex-grow: 1; /* Ensures the link text takes up available space */
            text-align: left; /* Aligns link text to the left */
        }
        .main-card ul li a:hover {
            color: var(--hover-color);
        }
        .main-card ul li button {
            background-color: var(--primary-color);
            color: white;
            border: none;
            padding: 8px 12px;
            border-radius: var(--radius);
            cursor: pointer;
            transition: background-color 0.3s ease, transform 0.3s ease;
        }
        .main-card ul li button:hover {
            background-color: var(--hover-color);
            transform: translateY(-2px);
        }

        form input[type="text"],
        form input[type="number"],
        form button {
            padding: 12px;
            margin: 8px 0;
            width: 100%;
            box-sizing: border-box;
            font-size: 1em;
            border: 1px solid var(--border-color);
            border-radius: var(--radius);
        }
        form button {
            background-color: var(--primary-color);
            color: white;
            border: none;
            cursor: pointer;
            transition: background-color 0.3s ease, transform 0.3s ease;
        }
        form button:hover {
            background-color: var(--hover-color);
            transform: translateY(-2px);
        }
        .footer {
            text-align: center;
            margin-top: 40px;
            font-size: 0.9em;
            color: #aaa;
        }

        /* Responsive Design */
        @media (max-width: 768px) {
            .dashboard {
                flex-direction: column;
                align-items: center;
            }
            .card {
                max-width: 100%;
            }
            .main-card {
                max-width: 100%;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>Client Dashboard</h1>
            <button onclick="firebase.auth().signOut().then(() => window.location.href = 'logout.php')" class="logout-btn">Logout</button>
        </div>

        <div class="dashboard">
            <!-- Combined Details and Add New IP -->
            <div class="combined-card">
                <h2>Details</h2>
                <p><strong>Email:</strong> <?= $_SESSION['email'] ?></p>
                <p><strong>Subscription Type:</strong> <?= ucfirst($userData['subscription']['type']) ?></p>
                <p><strong>Start Date:</strong> <?= $userData['subscription']['startDate'] ?></p>
                <p><strong>Expiration Date:</strong> <?= $userData['subscription']['endDate'] ?></p>
                <p><strong>Telegram Chat ID:</strong> <?= htmlspecialchars($userData['telegramChatId']) ?></p>
                <hr>
                <h3>Add New IP</h3>
                <form id="addIpForm">
                    <input type="text" name="ip_address" placeholder="IP Address" required>
                    <input type="number" name="port" placeholder="Port" required>
                    <input type="text" name="url" placeholder="URL">
                    <button type="submit">Add IP</button>
                </form>
            </div>

            <!-- IP Addresses -->
            <div class="main-card">
                <h2>Your IP Addresses</h2>
                <ul id="ipList">
                    <?php foreach ($ipAddresses as $ip): ?>
                        <li>
                            <a href="<?= htmlspecialchars($ip['url']) ?>" target="_blank">
                                <?= htmlspecialchars($ip['ipAddress']) ?>:<?= htmlspecialchars($ip['port']) ?> - <?= htmlspecialchars($ip['url']) ?>
                            </a>
                            <button onclick="deleteIp('<?= $ip['id'] ?>')" class="delete-btn">Delete</button>
                        </li>
                    <?php endforeach; ?>
                </ul>
            </div>
        </div>
    </div>

    <!-- Add Firebase SDK -->
    <script src="https://www.gstatic.com/firebasejs/11.0.2/firebase-app-compat.js"></script>
    <script src="https://www.gstatic.com/firebasejs/11.0.2/firebase-auth-compat.js"></script>
    <script src="https://www.gstatic.com/firebasejs/11.0.2/firebase-firestore-compat.js"></script>
    <script src="public/firebase-config.js"></script>

    <script>
        // Add IP Form Handler
        document.getElementById('addIpForm').addEventListener('submit', async (e) => {
            e.preventDefault();
            const formData = new FormData(e.target);
            
            try {
                const response = await fetch('add_ip.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        ip_address: formData.get('ip_address'),
                        port: formData.get('port'),
                        url: formData.get('url')
                    })
                });

                if (response.ok) {
                    window.location.reload();
                } else {
                    throw new Error('Failed to add IP');
                }
            } catch (error) {
                alert(error.message);
            }
        });

        // Delete IP Handler
        async function deleteIp(ipId) {
            if (!confirm('Are you sure you want to delete this IP?')) return;
            
            try {
                const response = await fetch('delete_ip.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ ip_id: ipId })
                });

                if (response.ok) {
                    window.location.reload();
                } else {
                    throw new Error('Failed to delete IP');
                }
            } catch (error) {
                alert(error.message);
            }
        }
    </script>
</body>
</html>
