<?php
session_start();
require_once 'includes/firebase_init.php';
require_once 'includes/analytics_helper.php';

if (!isset($_SESSION['authenticated'])) {
    http_response_code(401);
    echo json_encode(['error' => 'Unauthorized']);
    exit();
}

$analytics = new AnalyticsHelper($_SESSION['user_id']);
$firebase = FirebaseInit::getInstance();
$firestore = $firebase->getFirestore();

try {
    $ips = $firestore->collection('users')
        ->document($_SESSION['user_id'])
        ->collection('ip_addresses')
        ->documents();
    
    $stats = [];
    foreach ($ips as $ip) {
        $ipData = $ip->data();
        $stats[] = [
            'address' => $ipData['ipAddress'],
            'port' => $ipData['port'],
            'uptime_24h' => $analytics->getUptime($ip->id(), 'day'),
            'uptime_7d' => $analytics->getUptime($ip->id(), 'week'),
            'uptime_30d' => $analytics->getUptime($ip->id(), 'month'),
            'last_check' => $ipData['lastCheck'] ?? null
        ];
    }
    
    echo json_encode($stats);
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => $e->getMessage()]);
}
?> 