<?php
class AnalyticsHelper {
    private $firestore;
    private $userId;
    
    public function __construct($userId = null) {
        $firebase = FirebaseInit::getInstance();
        $this->firestore = $firebase->getFirestore();
        $this->userId = $userId;
    }
    
    public function logCheck($ipAddress, $port, $status) {
        return $this->firestore->collection('analytics')->add([
            'userId' => $this->userId,
            'ipAddress' => $ipAddress,
            'port' => $port,
            'status' => $status,
            'timestamp' => new \Google\Cloud\Core\Timestamp(new \DateTime())
        ]);
    }
    
    public function getUptime($ipId, $period = 'day') {
        $query = $this->firestore->collection('analytics')
            ->where('ipId', '=', $ipId);
            
        switch ($period) {
            case 'day':
                $start = new DateTime('24 hours ago');
                break;
            case 'week':
                $start = new DateTime('7 days ago');
                break;
            case 'month':
                $start = new DateTime('30 days ago');
                break;
            default:
                $start = new DateTime('24 hours ago');
        }
        
        $query = $query->where('timestamp', '>=', new \Google\Cloud\Core\Timestamp($start));
        $snapshots = $query->documents();
        
        $total = 0;
        $up = 0;
        foreach ($snapshots as $snapshot) {
            $total++;
            if ($snapshot['status'] === 'up') {
                $up++;
            }
        }
        
        return $total > 0 ? ($up / $total) * 100 : 100;
    }
    
    public function getUserStats() {
        return [
            'total_checks' => $this->getTotalChecks(),
            'uptime_percentage' => $this->getAverageUptime(),
            'downtime_incidents' => $this->getDowntimeIncidents(),
            'response_times' => $this->getAverageResponseTimes()
        ];
    }
    
    private function getTotalChecks() {
        return $this->firestore->collection('analytics')
            ->where('userId', '=', $this->userId)
            ->documents()
            ->size();
    }
    
    private function getDowntimeIncidents() {
        $yesterday = new DateTime('24 hours ago');
        return $this->firestore->collection('analytics')
            ->where('userId', '=', $this->userId)
            ->where('status', '=', 'down')
            ->where('timestamp', '>=', new \Google\Cloud\Core\Timestamp($yesterday))
            ->documents()
            ->size();
    }
} 