<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Register</title>
    <link rel="stylesheet" href="styles.css">
    
    <!-- Add Firebase SDK -->
    <script src="https://www.gstatic.com/firebasejs/11.0.2/firebase-app-compat.js"></script>
    <script src="https://www.gstatic.com/firebasejs/11.0.2/firebase-auth-compat.js"></script>
    <script src="https://www.gstatic.com/firebasejs/11.0.2/firebase-firestore-compat.js"></script>
    <script src="public/firebase-config.js"></script>
</head>
<body>
    <div class="container">
        <h1>Register</h1>
        <div id="error" style="color: red;"></div>
        <form id="registerForm">
            <label for="email">Email:</label>
            <input type="email" id="email" name="email" required>
            <label for="password">Password:</label>
            <input type="password" id="password" name="password" required>
            <label for="telegram">Telegram Chat ID:</label>
            <input type="text" id="telegram" name="telegram" required>
            <button type="submit">Register</button>
        </form>
        <p>Already have an account? <a href="login.php">Login here</a></p>
    </div>

    <script>
        document.getElementById('registerForm').addEventListener('submit', async (e) => {
            e.preventDefault();
            const email = document.getElementById('email').value;
            const password = document.getElementById('password').value;
            const telegramId = document.getElementById('telegram').value;
            
            try {
                // Create user in Firebase Auth
                const userCredential = await firebase.auth().createUserWithEmailAndPassword(email, password);
                const user = userCredential.user;
                
                // Store additional user data in Firestore
                const db = firebase.firestore();
                await db.collection('users').doc(user.uid).set({
                    email: email,
                    telegramChatId: telegramId,
                    createdAt: firebase.firestore.FieldValue.serverTimestamp(),
                    subscription: {
                        type: 'free',
                        startDate: new Date().toISOString(),
                        endDate: new Date(Date.now() + 30 * 24 * 60 * 60 * 1000).toISOString() // 30 days trial
                    }
                });

                // Get the ID token
                const idToken = await user.getIdToken();
                
                // Send token to backend
                const response = await fetch('verify_firebase_token.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ idToken, isNewUser: true })
                });
                
                if (response.ok) {
                    window.location.href = 'dashboard.php';
                } else {
                    throw new Error('Registration failed');
                }
            } catch (error) {
                document.getElementById('error').textContent = error.message;
            }
        });
    </script>
</body>
</html> 