<?php
session_start();
require_once 'includes/firebase_init.php';

$data = json_decode(file_get_contents('php://input'), true);
$idToken = $data['idToken'] ?? null;

if (!$idToken) {
    http_response_code(400);
    echo json_encode(['error' => 'No token provided']);
    exit;
}

try {
    $firebase = FirebaseInit::getInstance();
    $auth = $firebase->getAuth();
    $firestore = $firebase->getFirestore();
    
    // Verify the token
    $verifiedIdToken = $auth->verifyIdToken($idToken);
    $uid = $verifiedIdToken->claims()->get('sub');
    $email = $verifiedIdToken->claims()->get('email');
    
    // Get user data from Firestore
    $userDoc = $firestore->collection('users')->document($uid)->snapshot();
    
    if (!$userDoc->exists()) {
        throw new Exception('User data not found');
    }
    
    $userData = $userDoc->data();
    
    // Set session variables
    $_SESSION['authenticated'] = true;
    $_SESSION['user_id'] = $uid;
    $_SESSION['email'] = $email;
    $_SESSION['role'] = $userData['role'] ?? 'user';
    $_SESSION['is_admin'] = ($userData['role'] ?? 'user') === 'admin';
    
    echo json_encode([
        'success' => true,
        'user' => [
            'email' => $email,
            'role' => $userData['role'] ?? 'user',
            'is_admin' => ($userData['role'] ?? 'user') === 'admin'
        ]
    ]);
} catch (Exception $e) {
    http_response_code(401);
    echo json_encode(['error' => $e->getMessage()]);
} 